globalVariables(".data")

#' tabr: Guitar tablature and sheet music engraving.
#'
#' The \code{tabr} package provides programmatic music notation and wraps around the open source music engraving program, LilyPond, for creating quality guitar tablature.
#'
#' @docType package
#' @name tabr
NULL

#' Pipe operator
#'
#' See \code{magrittr::\link[magrittr]{\%>\%}} for details.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @export
#' @importFrom magrittr %>%
#' @usage lhs \%>\% rhs
NULL

#' @importFrom dplyr tibble
NULL
